@@ -1,8 +1,11 @@
 """Test :mod:`certbot.display.util`."""
 import inspect
 import os
+import socket
+import tempfile
 import unittest
 
+import six
 import mock
 
 from certbot import errors
@@ -15,6 +18,41 @@ CHOICES = [("First", "Description1"), ("Second", "Description2")]
 TAGS = ["tag1", "tag2", "tag3"]
 TAGS_CHOICES = [("1", "tag1"), ("2", "tag2"), ("3", "tag3")]
 
+
+class InputWithTimeoutTest(unittest.TestCase):
+    """Tests for certbot.display.util.input_with_timeout."""
+    @classmethod
+    def _call(cls, *args, **kwargs):
+        from certbot.display.util import input_with_timeout
+        return input_with_timeout(*args, **kwargs)
+
+    def test_eof(self):
+        with tempfile.TemporaryFile("r+") as f:
+            with mock.patch("certbot.display.util.sys.stdin", new=f):
+                self.assertRaises(EOFError, self._call)
+
+    def test_input(self, prompt=None):
+        expected = "foo bar"
+        stdin = six.StringIO(expected + "\n")
+        with mock.patch("certbot.display.util.select.select") as mock_select:
+            mock_select.return_value = ([stdin], [], [],)
+            self.assertEqual(self._call(prompt), expected)
+
+    @mock.patch("certbot.display.util.sys.stdout")
+    def test_input_with_prompt(self, mock_stdout):
+        prompt = "test prompt: "
+        self.test_input(prompt)
+        mock_stdout.write.assert_called_once_with(prompt)
+        mock_stdout.flush.assert_called_once_with()
+
+    def test_timeout(self):
+        stdin = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+        stdin.bind(('', 0))
+        stdin.listen(1)
+        with mock.patch("certbot.display.util.sys.stdin", stdin):
+            self.assertRaises(errors.Error, self._call, timeout=0.001)
+
+
 class FileOutputDisplayTest(unittest.TestCase):
     """Test stdout display.
 
@@ -35,7 +73,8 @@ class FileOutputDisplayTest(unittest.TestCase):
         self.assertTrue("message" in string)
 
     def test_notification_pause(self):
-        with mock.patch("six.moves.input", return_value="enter"):
+        input_with_timeout = "certbot.display.util.input_with_timeout"
+        with mock.patch(input_with_timeout, return_value="enter"):
             self.displayer.notification("message", force_interactive=True)
 
         self.assertTrue("message" in self.mock_stdout.write.call_args[0][0])
@@ -72,13 +111,15 @@ class FileOutputDisplayTest(unittest.TestCase):
         self.assertEqual(result, (display_util.OK, default))
 
     def test_input_cancel(self):
-        with mock.patch("six.moves.input", return_value="c"):
+        input_with_timeout = "certbot.display.util.input_with_timeout"
+        with mock.patch(input_with_timeout, return_value="c"):
             code, _ = self.displayer.input("message", force_interactive=True)
 
         self.assertTrue(code, display_util.CANCEL)
 
     def test_input_normal(self):
-        with mock.patch("six.moves.input", return_value="domain.com"):
+        input_with_timeout = "certbot.display.util.input_with_timeout"
+        with mock.patch(input_with_timeout, return_value="domain.com"):
             code, input_ = self.displayer.input("message", force_interactive=True)
 
         self.assertEqual(code, display_util.OK)
@@ -104,23 +145,24 @@ class FileOutputDisplayTest(unittest.TestCase):
                               self.displayer.input, "msg", cli_flag="--flag")
 
     def test_yesno(self):
-        with mock.patch("six.moves.input", return_value="Yes"):
+        input_with_timeout = "certbot.display.util.input_with_timeout"
+        with mock.patch(input_with_timeout, return_value="Yes"):
             self.assertTrue(self.displayer.yesno(
                 "message", force_interactive=True))
-        with mock.patch("six.moves.input", return_value="y"):
+        with mock.patch(input_with_timeout, return_value="y"):
             self.assertTrue(self.displayer.yesno(
                 "message", force_interactive=True))
-        with mock.patch("six.moves.input", side_effect=["maybe", "y"]):
+        with mock.patch(input_with_timeout, side_effect=["maybe", "y"]):
             self.assertTrue(self.displayer.yesno(
                 "message", force_interactive=True))
-        with mock.patch("six.moves.input", return_value="No"):
+        with mock.patch(input_with_timeout, return_value="No"):
             self.assertFalse(self.displayer.yesno(
                 "message", force_interactive=True))
-        with mock.patch("six.moves.input", side_effect=["cancel", "n"]):
+        with mock.patch(input_with_timeout, side_effect=["cancel", "n"]):
             self.assertFalse(self.displayer.yesno(
                 "message", force_interactive=True))
 
-        with mock.patch("six.moves.input", return_value="a"):
+        with mock.patch(input_with_timeout, return_value="a"):
             self.assertTrue(self.displayer.yesno(
                 "msg", yes_label="Agree", force_interactive=True))
 
@@ -128,7 +170,7 @@ class FileOutputDisplayTest(unittest.TestCase):
         self.assertTrue(self._force_noninteractive(
             self.displayer.yesno, "message", default=True))
 
-    @mock.patch("certbot.display.util.six.moves.input")
+    @mock.patch("certbot.display.util.input_with_timeout")
     def test_checklist_valid(self, mock_input):
         mock_input.return_value = "2 1"
         code, tag_list = self.displayer.checklist(
@@ -136,21 +178,21 @@ class FileOutputDisplayTest(unittest.TestCase):
         self.assertEqual(
             (code, set(tag_list)), (display_util.OK, set(["tag1", "tag2"])))
 
-    @mock.patch("certbot.display.util.six.moves.input")
+    @mock.patch("certbot.display.util.input_with_timeout")
     def test_checklist_empty(self, mock_input):
         mock_input.return_value = ""
         code, tag_list = self.displayer.checklist("msg", TAGS, force_interactive=True)
         self.assertEqual(
             (code, set(tag_list)), (display_util.OK, set(["tag1", "tag2", "tag3"])))
 
-    @mock.patch("certbot.display.util.six.moves.input")
+    @mock.patch("certbot.display.util.input_with_timeout")
     def test_checklist_miss_valid(self, mock_input):
         mock_input.side_effect = ["10", "tag1 please", "1"]
 
         ret = self.displayer.checklist("msg", TAGS, force_interactive=True)
         self.assertEqual(ret, (display_util.OK, ["tag1"]))
 
-    @mock.patch("certbot.display.util.six.moves.input")
+    @mock.patch("certbot.display.util.input_with_timeout")
     def test_checklist_miss_quit(self, mock_input):
         mock_input.side_effect = ["10", "c"]
 
@@ -182,7 +224,7 @@ class FileOutputDisplayTest(unittest.TestCase):
                 self.displayer._scrub_checklist_input(list_, TAGS))
             self.assertEqual(set_tags, exp[i])
 
-    @mock.patch("certbot.display.util.six.moves.input")
+    @mock.patch("certbot.display.util.input_with_timeout")
     def test_directory_select(self, mock_input):
         # pylint: disable=star-args
         args = ["msg", "/var/www/html", "--flag", True]
@@ -246,11 +288,12 @@ class FileOutputDisplayTest(unittest.TestCase):
 
     def test_get_valid_int_ans_valid(self):
         # pylint: disable=protected-access
-        with mock.patch("six.moves.input", return_value="1"):
+        input_with_timeout = "certbot.display.util.input_with_timeout"
+        with mock.patch(input_with_timeout, return_value="1"):
             self.assertEqual(
                 self.displayer._get_valid_int_ans(1), (display_util.OK, 1))
         ans = "2"
-        with mock.patch("six.moves.input", return_value=ans):
+        with mock.patch(input_with_timeout, return_value=ans):
             self.assertEqual(
                 self.displayer._get_valid_int_ans(3),
                 (display_util.OK, int(ans)))
@@ -262,8 +305,9 @@ class FileOutputDisplayTest(unittest.TestCase):
             ["4", "one", "C"],
             ["c"],
         ]
+        input_with_timeout = "certbot.display.util.input_with_timeout"
         for ans in answers:
-            with mock.patch("six.moves.input", side_effect=ans):
+            with mock.patch(input_with_timeout, side_effect=ans):
                 self.assertEqual(
                     self.displayer._get_valid_int_ans(3),
                     (display_util.CANCEL, -1))
