@@ -9,19 +9,19 @@ from certbot import achallenges
 from certbot.tests import acme_util
 
 
-class FaiiledChallengesTest(unittest.TestCase):
+class FailedChallengesTest(unittest.TestCase):
     """Tests for certbot.errors.FailedChallenges."""
 
     def setUp(self):
         from certbot.errors import FailedChallenges
         self.error = FailedChallenges(set([achallenges.DNS(
             domain="example.com", challb=messages.ChallengeBody(
-                chall=acme_util.DNS, uri=None,
+                chall=acme_util.DNS01, uri=None,
                 error=messages.Error(typ="tls", detail="detail")))]))
 
     def test_str(self):
         self.assertTrue(str(self.error).startswith(
-            "Failed authorization procedure. example.com (dns): tls"))
+            "Failed authorization procedure. example.com (dns-01): tls"))
 
 
 class StandaloneBindErrorTest(unittest.TestCase):
